import matplotlib.pyplot as plt
import matplotlib.lines as lines


def descriptive_plot(figsize=(8, 6), line_pos_x_axis=1, background_color='#fbfbfb'):
    fig, ax = plt.subplots(1, 1, figsize=figsize, facecolor=background_color)

    ax.set_facecolor(background_color)

    line = lines.Line2D([line_pos_x_axis, line_pos_x_axis], [0, 1], transform=fig.transFigure, figure=fig,
                        color='black', lw=0.4)
    fig.lines.extend([line])

    return ax


def vertical_descriptive_plot(figsize=(6, 8), plots=3, plot_height=0.5, plot_width=0.75, background_color='#fbfbfb'):
    if plot_width > 1.4:
        raise Exception('Plot width cannot be greater than 1.5')

    fig = plt.figure(figsize=figsize, facecolor='#fbfbfb')
    axes = []

    initial_axis = 0
    for _ in range(plots):
        axis = fig.add_axes([0, initial_axis, plot_width, plot_height])
        axis.set_facecolor(background_color)
        axes.append(axis)
        initial_axis += plot_height + 0.1

    line_length = (plot_height + 0.1) * plots
    line = lines.Line2D([plot_width + 0.1, plot_width + 0.1], [0 - 0.1, line_length], transform=fig.transFigure,
                        figure=fig, color='black', lw=0.4)
    fig.lines.extend([line])

    return axes


def horizontal_descriptive_plot(figsize=(8, 6), plots=3, plot_height=0.75, line_pos_y_axis=-0.1,
                                background_color='#fbfbfb'):
    if plots not in [2, 3, 4]:
        raise Exception('Number of plots must be 2, 3 or 4')

    # Plot Position on X-axis
    increment = {2: 1, 3: 0.7, 4: 0.5}

    # Plot width based on number of plots required
    plot_width = {2: 0.9, 3: 0.6, 4: 0.43}

    fig = plt.figure(figsize=figsize, facecolor='#fbfbfb')
    axes = []

    initial_axis = 0
    for _ in range(plots):
        axis = fig.add_axes([initial_axis, 0, plot_width[plots], plot_height])
        axis.set_facecolor(background_color)
        axes.append(axis)
        initial_axis += increment[plots]

    line_length = increment[plots] * (plots - 1) + plot_width[plots]
    line = lines.Line2D([0 - 0.1, line_length + 0.1], [line_pos_y_axis, line_pos_y_axis], transform=fig.transFigure,
                        figure=fig, color='black', lw=0.4)
    fig.lines.extend([line])

    return axes



import seaborn as sns
import urllib.request as req
from IPython.core.display import HTML


def load_css(theme=None):
    response_main = req.urlopen(
        'https://raw.githubusercontent.com/sprakshith/TechDeciphersStyles/main/static/main.css')

    if theme == 'cyan_sisters':
        response_theme = req.urlopen(
            'https://raw.githubusercontent.com/sprakshith/TechDeciphersStyles/main/static/cyan_sisters.css')
        return HTML('<style>' + response_main.read().decode('utf-8') +
                    response_theme.read().decode('utf-8') + '</style>')
    if theme == 'dark_matter':
        response_theme = req.urlopen(
            'https://raw.githubusercontent.com/sprakshith/TechDeciphersStyles/main/static/cyan_sisters.css')
        return HTML('<style>' + response_main.read().decode('utf-8') +
                    response_theme.read().decode('utf-8') + '</style>')
    else:
        response_theme = req.urlopen(
            'https://raw.githubusercontent.com/sprakshith/TechDeciphersStyles/main/static/cyan_sisters.css')
        return HTML('<style>' + response_main.read().decode('utf-8') +
                    response_theme.read().decode('utf-8') + '</style>')


def get_color_palette(theme=None):
    if theme == 'cyan_sisters':
        colors = ['#cadeef', '#9bd4e4', '#39ace7', '#0784b5']
        return sns.color_palette(colors)
    else:
        return sns.color_palette("tab10")



from setuptools import setup, find_packages

classifiers = [
    'Development Status :: 3 - Alpha',
    'Operating System :: OS Independent',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Intended Audience :: Developers',
]

setup(
    name='tdstyles',
    version='0.0.4',
    description='A python package which helps in customizing a jupyter notebook with very less effort.',
    long_description=open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),
    url='https://sprakshith.pythonanywhere.com/',
    author='SP RAKSHITH',
    author_email='rakshith0908@gmail.com',
    license='MIT',
    classifiers=classifiers,
    keywords='matplotlib pyplot seaborn plt sns',
    packages=find_packages(),
    install_requires=['matplotlib', 'IPython', 'seaborn']
)
